#
# spec file for package python-pytest-trio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-trio
Version:        0.8.0
Release:        3.1
Summary:        Pytest plugin for trio
License:        Apache-2.0 OR MIT
URL:            https://github.com/python-trio/pytest-trio
Source:         https://github.com/python-trio/pytest-trio/archive/v%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-outcome >= 1.1.0
Requires:       python-pytest >= 7.2.0
Requires:       python-trio >= 0.22.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module hypothesis >= 3.64}
BuildRequires:  %{python_module outcome >= 1.1.0}
# we really need newer pytest in tests than is required by the package
BuildRequires:  %{python_module pytest >= 7.2.0}
BuildRequires:  %{python_module trio >= 0.22.0}
# /SECTION
%python_subpackages

%description
This is a pytest plugin to help you test projects that use Trio,
a friendly library for concurrency and async I/O in Python.

%prep
%autosetup -p1 -n pytest-trio-%{version}

rm pytest.ini
rm pytest_trio/_tests/test_hypothesis_interaction.py
mv pytest_trio/_tests/ tests

%build
%python_build

%install
%python_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE LICENSE.APACHE2 LICENSE.MIT
%{python_sitelib}/pytest_trio
%{python_sitelib}/pytest_trio-%{version}*-info

%changelog
* Wed Apr 10 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed python-contextvars dependency
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Dec 13 2022 Markéta Machová <mmachova@suse.com>
- Update to 0.8.0
  * If a test raises an ExceptionGroup (or nested ExceptionGroups)
    with only a single ‘leaf’ exception from pytest.xfail() or
    pytest.skip(), we now unwrap it to have the desired effect on Pytest.
  * Trio 0.22.0 deprecated MultiError in favor of the standard-library
    (or backported) ExceptionGroup type; pytest-trio now uses ExceptionGroup
    exclusively and therefore requires Trio 0.22.0 or later. (#128)
  * Dropped support for end-of-life Python 3.6, and the async_generator library
    necessary to support it, and started testing on Python 3.10 and 3.11. (#129)
* Thu Nov  5 2020 Marketa Machova <mmachova@suse.com>
- Update to 0.7.0
  * Support added for alternative Trio run functions via the trio_run
    configuration variable and @pytest.mark.trio(run=...).  Presently
    supports Trio and QTrio.
  * Python 3.5 support removed.
  * pytest 6 support added
- Drop merged pytest6.patch
* Sun Oct 11 2020 John Vandenberg <jayvdb@gmail.com>
- Add missing runtime dependency on contextvars
- Deactivate low value hypothesis generated tests
- Remove use of pytest-cov in %%check
- Remove tests from runtime package
* Tue Aug 25 2020 Marketa Calabkova <mcalabkova@suse.com>
- Add patch pytest6.patch to fix build
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.0:
  * Incompatible change: if you use yield inside a Trio fixture,
    and the yield gets cancelled (for example, due to a background
    task crashing), then the yield will now raise :exc:`trio.Cancelled`.
  * Updated for compatibility with Trio v0.15.0.
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Add a temporary hack in the spec to alter the conftest.py used
  when testing the plugin, fixing the builds.
- Remove unnecessary build dependency on python-devel
* Sat May 11 2019 Torsten Gruner <t.gruner@katodev.de>
- Initial release version 0.5.2
